@@ -55,15 +55,22 @@ const char* help =
 "        supported by compilers like GCC, Clang and Tcc. The main advantage over\n"
 "        using single cases is smaller generated code and faster generation\n"
 "        time, although for some compilers like Tcc it also results in smaller\n"
-"        binary size. This option is supported only for C.\n"
+"        binary size.\n"
 "\n"
 "    --computed-gotos -g\n"
 "\n"
 "        Optimize conditional jumps using non-standard \"computed goto\" extension\n"
 "        (which must be supported by the compiler). re2go generates jump tables\n"
 "        only in complex cases with a lot of conditional branches. Complexity\n"
-"        threshold can be configured with cgoto:threshold configuration. This\n"
-"        option implies --bit-vectors. It is supported only for C.\n"
+"        threshold can be configured with cgoto:threshold configuration.\n"
+"        Relative offsets can be enabled with cgoto:relative configuration. This\n"
+"        option implies --bit-vectors.\n"
+"\n"
+"    --computed-gotos-relative\n"
+"\n"
+"        Similar to --computed-gotos but generate relative offsets for jump\n"
+"        tables instead (which must be supported by the compiler). This option\n"
+"        implies --computed-gotos.\n"
 "\n"
 "    --conditions --start-conditions -c\n"
 "\n"
@@ -146,13 +153,13 @@ const char* help =
 "        (...) is capturing and (! ...) is non-capturing. With this option (!\n"
 "        ...) is capturing and (...) is non-capturing.\n"
 "\n"
-"    --lang <none | c | d | go | haskell | java | js | ocaml | python | rust | v\n"
-"    | zig>\n"
+"    --lang <none | c | d | go | haskell | java | js | ocaml | python | rust |\n"
+"    swift | v | zig>\n"
 "\n"
 "        Specify the target language. Supported languages are C, D, Go, Haskell,\n"
-"        Java, JS, OCaml, Python, Rust, V, Zig (more languages can be added via\n"
-"        user-defined syntax files, see the --syntax option). Option none\n"
-"        disables default suntax configs, so that the target language is\n"
+"        Java, JS, OCaml, Python, Rust, Swift, V, Zig (more languages can be\n"
+"        added via user-defined syntax files, see the --syntax option). Option\n"
+"        none disables default suntax configs, so that the target language is\n"
 "        undefined.\n"
 "\n"
 "    --location-format <gnu | msvc>\n"
